==> flowtask-5.2.6-cp310-cp310-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: flowtask/hooks/interfaces/task.py <==
"""
Flowtask Task Execution.
"""
from typing import Optional
import asyncio
from navconfig.logging import logging
# Queue Worker Client:
from qw.client import QClient
from qw.wrappers import TaskWrapper
from flowtask.tasks.task import Task
from flowtask.exceptions import FlowTaskError, TaskFailed


class TaskSupport:
    def __init__(self, task: str, *args, **kwargs):
        self._name_ = self.__class__.__name__
        self.program: str = kwargs.pop('program', 'navigator')
        self.task: str = task
        # No worker:
        self._no_worker: bool = kwargs.pop('no_worker', False)
        if self._no_worker is False:
            self.worker: QClient = QClient()  # auto-discovering of workers
        else:
            self.worker: Optional[QClient] = None
        # self.worker = worker
        self.priority = kwargs.pop('priority', None)
        self.logger = logging.getLogger(
            f'Task.{self.program}.{self.task}'
        )
        self._args = args
        self._kwargs = kwargs

    def __repr__(self):
        return f'<Action.Task>{self.program}.{self.task}'

    async def run(self, *args, **kwargs):
        if self._no_worker is False:
            if self.priority == 'pub':
                # Using Channel Group mechanism (avoid queueing)
                try:
                    result = await self.worker.publish(self.wrapper)
                    await asyncio.sleep(.01)
                    return result
                except asyncio.TimeoutError:
                    raise
                except Exception as exc:
                    self.logger.error(f'{exc}')
                    raise
            else:
                try:
                    result = await self.worker.queue(self.wrapper)
                    await asyncio.sleep(.01)
                    return result
                except asyncio.TimeoutError:
                    raise
                except Exception as exc:
                    self.logger.error(f'{exc}')
                    raise
        else:
            try:
                await self.task.start()
            except Exception as exc:
                self.logger.error(exc)
                raise TaskFailed(
                    f"{exc!s}"
                ) from exc
            try:
                return await self.task.run()
            except Exception as err:
                raise TaskFailed(
                    f'Error: Task {self.program}.{self.task} failed: {err}'
                ) from err
            finally:
                await self.task.close()

    async def close(self):
        pass

    async def open(self):
        try:
            if self._no_worker is False:
                self.wrapper = TaskWrapper(
                    program=self.program,
                    task=self.task,
                    **self._kwargs
                )
            else:
                self.task = Task(
                    task=self.task,
                    program=self.program,
                    debug=True
                )
        except Exception as exc:
            self.logger.exception(
                str(exc), stack_info=True
            )
            raise FlowTaskError(
                f"Error: {exc}"
            ) from exc

==> flowtask-5.2.47-cp310-cp310-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: flowtask/hooks/interfaces/task.py <==
"""
Flowtask Task Execution.
"""
from typing import Optional
import asyncio
from navconfig.logging import logging

# Queue Worker Client:
from qw.client import QClient
from qw.wrappers import TaskWrapper
from ...tasks.task import Task
from ...exceptions import FlowTaskError, TaskFailed


class TaskSupport:
    def __init__(self, task: str, *args, **kwargs):
        self._name_ = self.__class__.__name__
        self.program: str = kwargs.pop("program", "navigator")
        self.task: str = task
        # No worker:
        self._no_worker: bool = kwargs.pop("no_worker", False)
        if self._no_worker is False:
            self.worker: QClient = QClient()  # auto-discovering of workers
        else:
            self.worker: Optional[QClient] = None
        # self.worker = worker
        self.priority = kwargs.pop("priority", None)
        self.logger = logging.getLogger(f"Task.{self.program}.{self.task}")
        self._args = args
        self._kwargs = kwargs

    def __repr__(self):
        return f"<Action.Task>{self.program}.{self.task}"

    async def run(self, *args, **kwargs):
        if self._no_worker is False:
            if self.priority == "pub":
                # Using Channel Group mechanism (avoid queueing)
                try:
                    result = await self.worker.publish(self.wrapper)
                    await asyncio.sleep(0.01)
                    return result
                except asyncio.TimeoutError:
                    raise
                except Exception as exc:
                    self.logger.error(f"{exc}")
                    raise
            else:
                try:
                    result = await self.worker.queue(self.wrapper)
                    await asyncio.sleep(0.01)
                    return result
                except asyncio.TimeoutError:
                    raise
                except Exception as exc:
                    self.logger.error(f"{exc}")
                    raise
        else:
            try:
                await self.task.start()
            except Exception as exc:
                self.logger.error(exc)
                raise TaskFailed(f"{exc!s}") from exc
            try:
                return await self.task.run()
            except Exception as err:
                raise TaskFailed(
                    f"Error: Task {self.program}.{self.task} failed: {err}"
                ) from err
            finally:
                await self.task.close()

    async def close(self):
        pass

    async def open(self):
        try:
            if self._no_worker is False:
                self.wrapper = TaskWrapper(
                    program=self.program, task=self.task, **self._kwargs
                )
            else:
                self.task = Task(task=self.task, program=self.program, debug=True)
        except Exception as exc:
            self.logger.exception(str(exc), stack_info=True)
            raise FlowTaskError(f"Error: {exc}") from exc
